@@ -1,15 +1,32 @@
 #!/usr/bin/env python
 """
-Devapp Project Creation
+# Creating A Project With Resources
 
-By providing the --init_at <project dir> switch we will (re-)initialize a project directory there, incl:
+This plugin is helper for creating a project directory, incl. required local resources.
+Your system remains unchanged, except <project_dir> and <conda_prefix>.
+
+It provides an `install` action (implicitely by providing the --init_resource_match or --init_at switch)
+
+Default action is: `list` (show installable resources, -m <match> filters).
+
+At install we will (re-)initialize a "project_dir", at location given with --init_at (default: '.'), incl:
 
 - Installing available resources, like databases and tools within a given directory (conda_prefix)
+
 - Creating resource start wrappers in <project_dir>/bin
-- Creating a 
 
-Privilege escalation is not required for any of these steps, your system remains unchanged, except <project_dir> and <conda_prefix>
+- Generating default config when required
 
+- Optionally generating systemd unit files (e.g. via: --init_create_all_units)
+
+- Instances support: export <name>_instances=x before running and you'll get x systemd units created, for startable commands.
+    Example: export client_instances=10; ops p -irm client -icau
+    (Name of a resource: ops p [-m <match>])
+
+- Any other parametrization: Via environ variables
+  Check key environ vars in list output and also doc text.
+
+Privilege escalation is not required for any of these steps.
 """
 # Could be done far smaller.
 from re import match
@@ -51,8 +68,7 @@ class Flags(api.CommonFlags):
         d = False
 
     class init_at:
-        n = 'Set up project in given directory. env vars / relative dirs supported.'
-        d = ''
+        n = 'Set up project in given directory. env vars / relative dirs supported. Sets install action implicitly'
 
     class dev_install:
         n = 'Set the project up in developer mode - incl. make and poetry file machinery'
@@ -63,21 +79,23 @@ class Flags(api.CommonFlags):
         d = False
 
     class init_create_unit_files:
-        'Valid: Entries in rsc.provides, rsc.cmd or rsc.exe (i.e. the filename of the wrapper in bin dir). Not: rsc.name.'
+        """Valid: Entries in rsc.provides, rsc.cmd or rsc.exe (i.e. the filename of the wrapper in bin dir). Not: rsc.name."""
+
         n = 'List service unit files you want to have created for systemctl --user.'
         d = []
 
-    class init_resource_match:
-        n = 'Install only matching resources. Examples: -irm "redis, hub" or -irm \'!mysql, !redis\' (! negates).'
+    class resource_match:
+        s = 'm'
+        n = 'Provide a match string for actions. Examples: -irm "redis, hub" or -irm \'!mysql, !redis\' (! negates).'
         d = []
 
-    class list_resources_files:
-        n = 'Show available definition files.'
-        d = False
+    class init_resource_match:
+        n = 'Like resource match but implies install action'
+        d = []
 
     class add_post_process_cmd:
         n = 'Add this to all commands which have systemd service units. Intended for output redirection. Not applied when stdout is a tty.\n'
-        n += '''Example: -appc='2>&1 | rotatelogs -e -n1 "$logfile" 1M' ($logfile defined in wrapper -> use single quotes).\n'''
+        n += """Example: -appc='2>&1 | rotatelogs -e -n1 "$logfile" 1M' ($logfile defined in wrapper -> use single quotes).\n"""
         n += 'Tip: Use rotatelogs only on powers of 10 - spotted problems with 200M. Use 100M or 1G in that case.'
         d = ''
 
@@ -89,6 +107,18 @@ class Flags(api.CommonFlags):
         n = 'This removes all matching unit files calling devapp service wrappers. Say "service" to match all'
         d = ''
 
+    class Actions:
+        class list:
+            n = 'Show available definition files.'
+            d = True
+
+        class list_resources_files:
+            n = 'Alias for list action'
+            d = False
+
+        class install:
+            d = False
+
 
 S = api.S
 
@@ -201,6 +231,7 @@ class disabled:
 
 def get_matching_resources():
     m = FLG.init_resource_match
+    m.extend(FLG.resource_match)
     negates = []
     for u in list(m):
         if u.startswith('!'):
@@ -209,8 +240,18 @@ def get_matching_resources():
     r = api.find_resource_defs()
     rscs = S.rscs_defined
     api.add_install_state(rscs)
-    matches = lambda r: any([_ in str(api.to_dict(r)) for _ in m])
-    rscs = [r for r in rscs if not m or matches(r)]
+    # matches = lambda r: any([_ in str(api.to_dict(r)) for _ in m])
+    def matches(rsc, m=m):
+        r = api.to_dict(rsc)
+        for _ in m:
+            if (
+                str(r.get('systemd')) == _
+                or str(r.get('cmd')).startswith(_)
+                or str(r.get('name')).startswith(_)
+            ):
+                return True
+
+    rscs = [r for r in rscs if not m or matches(r, m)]
     if negates:
         n = negates
         rscs = [r for r in rscs if not any([_ in str(api.to_dict(r)) for _ in n])]
@@ -225,11 +266,18 @@ def get_matching_resources():
 
 def run():
 
-    if FLG.list_resources_files:
+    if FLG.install or FLG.init_resource_match or FLG.init_at:
+        # backwards compat
+        FLG.init_at = FLG.init_at or '.'
+        FLG.list = False
+        FLG.install = True
+
+    if FLG.list_resources_files or FLG.list:
         rscs = get_matching_resources()
         app.info('Listing Defined Resources')
         app.info('details', json=rscs_dicts(rscs))
         return [r for r in rscs]
+
     m = FLG.delete_all_matching_service_unit_files
     if m:
         return do(delete_all_matching_service_unit_files, match=m)
@@ -240,18 +288,16 @@ def run():
     # the project directory:
     d = FLG.init_at
     if not d:
-        if FLG.dev_install:
-            FLG.init_at = d = '.'
-        else:
-            return app.error('No project dir given')
+        return app.error('No project dir given')
 
     d = repl_dollar_var_with_env_val(d)
     d = os.path.abspath(d)
     d = d[:-1] if d.endswith('/') else d
-    if exists(d):
-        do(os.chdir, d)
-        d = FLG.init_at = os.path.abspath('.')
-        project.set_project_dir(dir=d)
+    if not exists(d):
+        app.die('Not exists', dir=d)
+    do(os.chdir, d)
+    d = FLG.init_at = os.path.abspath('.')
+    project.set_project_dir(dir=d)
 
     rscs = get_matching_resources()
     project.set_project_dir(dir=d)
@@ -300,7 +346,7 @@ def run():
 
 # https://serverfault.com/a/1026914 - this is really relevant,
 # since RH and drives deployers crazy on first command!
-T_SDU_SVD = '''
+T_SDU_SVD = """
 We are using the systemd **user** service to manage processes. This means there is a systemd process that runs as unprivileged user. 
 The systemd user service is not used as commonly as the normal systemd process manager.
 For example Red Hat disabled the systemd user service in RHEL 7 (and thereby all distros that come from RHEL, like CentOS, Oracle Linux 7, Amazon Linux 2).
@@ -349,7 +395,7 @@ ________________________________________________________________________________
 Then enable and start the unit.
 
 Run `ps -fww $(pgrep -f "systemd --user")` to verify success, then try re-init the project.
-'''
+"""
 
 T_SDU_SVD = T_SDU_SVD.replace('_UID_', str(os.getuid()))
 
