@@ -1,7 +1,6 @@
 #!/usr/bin/env python
 """
 Common API for all resources
-
 """
 # FIXME Do this as state table! Its crying for that
 
@@ -24,7 +23,32 @@ from devapp.tools import (
     read_file,
 )
 
-T_unit = '''
+
+class S:
+    """state"""
+
+    is_mamba = True
+    rscs_defined = None  # from resource_list
+    pkg_cmd = None
+    rsc_modified = False
+    name_to_func = {}
+    conda_prefix = None  # env vars replaced
+    fs_dir = None  # filesystem install dest
+    constants = {}
+    rsc_dirs = {}
+
+
+# mamba support hack
+MRP = os.environ.get('MAMBA_ROOT_PREFIX')
+CP = os.environ.get('CONDA_PREFIX', '').split('/envs/')[0]
+if CP:
+    S.is_mamba = CP == MRP
+    MRP = CP
+
+os.environ['CONDA_PREFIX'] = CP
+
+
+T_unit = """
 [Unit]
 Description      = %(descr)s %(name)s
 Wants            = network-online.target
@@ -32,7 +56,7 @@ StopWhenUnneeded = false
 
 [Service]
 Type             = simple
-
+Environment      = INSTANCE=%(env_instance)s
 ExecStart        = %(exec_start)s
 KillSignal       = SIGTERM
 PrivateTmp       = true
@@ -46,24 +70,11 @@ SyslogIdentifier = %(name)s
 WantedBy = default.target
 
 # _MATCH_ (auto created %(ctime)s) 
-'''
+"""
 unit_match = 'DevApp Unit'
 T_unit = T_unit.replace('_MATCH_', unit_match)
 
 
-class S:
-    """state"""
-
-    rscs_defined = None  # from resource_list
-    pkg_cmd = None
-    rsc_modified = False
-    name_to_func = {}
-    conda_prefix = None  # env vars replaced
-    fs_dir = None  # filesystem install dest
-    constants = {}
-    rsc_dirs = {}
-
-
 def add_const(key, val, skip_exists=True):
     """import order matters, i.e. 4A's flows file will overrule lc-py"""
     v = S.constants.get(key)
@@ -87,7 +98,8 @@ environ = os.environ
 
 
 def cur_prefix():
-    cli = os.environ.get('CONDA_PREFIX', '').split('/envs/', 1)[0]
+    m = MRP
+    cli = os.environ.get('CONDA_PREFIX', m).split('/envs/', 1)[0]
     if not cli:
         app.die('No $CONDA_PREFIX currently set')
     return cli
@@ -101,7 +113,7 @@ def set_conda_prefix():
     - local|l: <project_dir>/conda
     - default|d: $HOME/miniconda3 (default path of conda)
     - current|c: Any current conda_prefix set when running.
-    
+
     Note: Installing resources outside the project keeps the project relocatable and resources reusable for other products.
     """
 
@@ -150,7 +162,7 @@ class CommonFlags:
 
     class conda_prefix:
         n = set_conda_prefix.__doc__
-        d = 'default'
+        d = MRP or 'default'
 
     class fs_dir:
         n = set_fs_dir.__doc__
@@ -309,6 +321,12 @@ class Run:
         return cmd, spec
 
 
+def get_instances(rsc):
+    n = rsc.name
+    i = int(os.environ.get(f'{n}_instances', '0'))
+    return i
+
+
 class Install:
     """Install methods"""
 
@@ -354,19 +372,22 @@ class Install:
             s = '--skip_filesystem_adaptions'
             system('ops container_build --dirs "%s.img" --target_dir "%s" %s' % (d, d, s))
 
-    def write_unit_file(name, fn, rsc):
+    def write_unit_file(name, fn, rsc, instance):
         pn = project.root().rsplit('/', 1)[-1]
+        inst_name = f'{name}-{instance}' if instance else name
         m = {
-            'name': name,
-            'descr': '%s %s ' % (g(rsc, 'n', name), pn),
+            'name': inst_name,
+            'descr': '%s %s ' % (g(rsc, 'n', inst_name), pn),
             'ctime': time.ctime(),
             'exec_start': fn,
+            'env_instance': instance if instance else '',
         }
         d = os.environ['HOME'] + '/.config/systemd/user'
         if not exists(d):
             app.info('creating systemd user dir', dir=d)
             os.makedirs(d)
-        n_svc = '%s-%s.service' % (name, pn)
+
+        n_svc = '%s-%s.service' % (inst_name, pn)
         sfn = d + '/' + n_svc
         unit = T_unit % m
         have = read_file(sfn, dflt='')
@@ -382,7 +403,7 @@ class Install:
         env['d_conf'] = project.root() + '/conf'
         env['d_bin'] = project.root() + '/bin'
 
-        def write(cmd, fcmd, spec):
+        def write(cmd, fcmd, spec, instance=0, scmds=[]):
             # if cmd == 'dot':
             #    breakpoint()  # FIXME BREAKPOINT
             if isinstance(spec, str):
@@ -423,22 +444,31 @@ class Install:
             has_unit = False
             if any([u for u in units if u == cmd]):
                 has_unit = True
-                n_svc = Install.write_unit_file(cmd, fn, rsc)
-                s = '''
+                n_svc = Install.write_unit_file(cmd, fn, rsc, instance)
+                scmd = f'systemctl --user --no-pager "$1" "{n_svc}"'
+                if instances:
+                    _ = f'\n        systemctl --user --no-pager "$1" "{n_svc}" '
+                    scmds.append(_)
+                    scmd = ''.join(scmds)
+                s = """
 
                 case "${1:-}" in
                     start|restart|stop|status)
-                        systemctl --user --no-pager $1 "%s"
+                        set -x
+                        _CMD_
                         exit $?
                         ;;
                 esac
-                '''
-                add(deindent(s % n_svc))
+                """
+                s = s.replace('_CMD_', scmd)
+                add(deindent(s))
 
             # env['PATH'] = '%s:$PATH' % g(rsc, 'path')
             add('')
             add("H='__HOME__'")
             add('export PROJECT_ROOT="%s"' % project.root())
+            add('# set e.g. in unit files:')
+            add('test -n "$INSTANCE" && inst_postfix="-$INSTANCE" || inst_postfix=""')
             add('')
             add('# Resource settings:')
             # for whoever needs that:
@@ -456,7 +486,7 @@ class Install:
             if 'logdir' not in allk:
                 add('export logdir="$PROJECT_ROOT/log"')
             if 'logfile' not in allk:
-                add('export logfile="$logdir/%s.log"' % cmd)
+                add('export logfile="$logdir/%s$inst_postfix.log"' % cmd)
 
             add('')
             # only for services. Tools not: (e.g. cd mydir && git status -> bum, differentdir)
@@ -497,7 +527,13 @@ class Install:
         for cmd in rsc_cmds(rsc):
             fcmd, spec = Run.get_full_cmd(rsc, cmd)
             cmd = cmd.rsplit('/', 1)[-1]  # /usr/bin/seagull -> bin/seagull
-            write(cmd, fcmd, spec)
+            instances = get_instances(rsc)
+            if not instances:
+                write(cmd, fcmd, spec)
+            else:
+                scmds = []
+                for i in range(instances):
+                    write(cmd, fcmd, spec, instance=i + 1, scmds=scmds)
 
     def requirements(req):
         if not req:
@@ -513,6 +549,7 @@ class Install:
 
             # return False if not dp else all([exists(dp + '/' + p) for p in rsc.provides])
             if not exists(D + '/bin/'):
+                app.warn('Conda base not fully installed')
                 do(Install.Conda.base, location=D)
 
             if str(rsc.path).startswith(D):
@@ -520,17 +557,42 @@ class Install:
 
             env = g(rsc, 'conda_env', rsc.name)
             ctx = dict(D=D, name=env, yes=interactive())
-            # source is not working for $0 = sh:
-            cmd = [
-                '. "%(D)s/etc/profile.d/conda.sh"',
-                'conda create %(yes)s -n "%(name)s"',
-                'conda activate "%(name)s"',
-            ]
+            mamba = os.environ.get('MAMBA_EXE')
+            # if os.system('type micromamba') == 0 or 1:
+            if S.is_mamba and mamba and MRP:
+                ctx['conda'] = mamba
+                # FIXME: The activate during docker build is a problem in micromamba which runs as subprocess
+                # Better create the env via micromamba create -n foo -f <yaml file> first
+                cmd = [
+                    '%(conda)s create %(yes)s -n "%(name)s"',
+                    f'. "{MRP}/etc/profile.d/micromamba.sh"',
+                    'micromamba activate "%(name)s"',
+                ]
+
+            elif S.is_mamba and mamba:
+                ctx['conda'] = mamba
+                # FIXME: The activate during docker build is a problem in micromamba which runs as subprocess
+                # Better create the env via micromamba create -n foo -f <yaml file> first
+                cmd = [
+                    '%(conda)s create %(yes)s -n "%(name)s"',
+                    'eval "$(%(conda)s shell hook --shell=bash)"',
+                    '%(conda)s activate "%(name)s"',
+                ]
+            else:
+                cmd = [
+                    'test -e "%(D)s/etc/profile.d/conda.sh" && . "%(D)s/etc/profile.d/conda.sh" || true',
+                    '%(conda)s create %(yes)s -n "%(name)s"',
+                    '%(conda)s activate "%(name)s"',
+                ]
+            ctx['conda'] = ctx.get('conda', 'conda')
             pth = '%(D)s/envs/%(name)s/bin/' % ctx
 
             if g(rsc, 'typ') == 'pip':
                 ctx['cmd'] = rsc.cmd
-                cmd += ['conda install python; %p/pip install %%(cmd)s' % pth]
+                cmd += [
+                    '%(conda)s install -c conda-forge python; %p/pip install %%(cmd)s'
+                    % pth
+                ]
             else:
                 icmd = g(rsc, 'conda_inst', '')
                 if icmd:
@@ -542,9 +604,14 @@ class Install:
                         chan = '-c ' + chan
                     ctx['chan'] = chan
                     ctx['pkg'] = p
-                    cmd += ['conda install %(yes)s %(chan)s %(pkg)s']
+                    cmd += ['%(conda)s install %(yes)s -c conda-forge %(chan)s %(pkg)s']
             cmd = ' && '.join(cmd) % ctx
             rsc.path = g(rsc, 'path') or pth
+
+            # app.info('cmd', cmd=cmd)
+            # import subprocess
+            # s = subprocess.run(cmd, shell=True, executable='/bin/bash')
+            # will run under dash, sh, bash -> problem e.g. for conda activate
             return do(system, cmd)
 
         def base(location):
